@@ -983,12 +983,15 @@ capture_generic (CameraCaptureType type, const char __unused__ *name, int downlo
 			 */
 		} else {
 			result = GP_ERROR_NOT_SUPPORTED;
+#if 0
+			/* Not a good idea, as we do not know how long to wait after capture ... */
 			if (a.operations & GP_OPERATION_TRIGGER_CAPTURE) {
 				result = gp_camera_trigger_capture (gp_params.camera, gp_params.context);
 				if ((result != GP_OK) && (result != GP_ERROR_NOT_SUPPORTED))
 					cli_error_print(_("Could not trigger image capture."));
 				/* The downloads will be handled by wait_event */
 			}
+#endif
 			if (result == GP_ERROR_NOT_SUPPORTED) {
 				result = gp_camera_capture (gp_params.camera, type, &path, gp_params.context);
 				if (result != GP_OK) {
@@ -1100,14 +1103,13 @@ capture_generic (CameraCaptureType type, const char __unused__ *name, int downlo
 	 */
 	gettimeofday (&expose_end_time, NULL);
 	waittime = 3000;
-	printf("Capture done, waiting %gs.\n",waittime/1000.0);
 	/* tricky, this loop might need to download both JPG and RAW. so wait longer. */
 	/*if (glob_frames || end_next || !glob_interval || glob_bulblength) waittime = 2000;*/
 	/* Drain the event queue at the end and download left over added images */
 	while (1) {
 		int realwait = waittime - (-timediff_now(&expose_end_time));
 		if (realwait < 0) realwait = 0; /* just drain the queue now */
-		result = wait_and_handle_event(waittime - (-timediff_now(&expose_end_time)), &evtype, download);
+		result = wait_and_handle_event(realwait, &evtype, download);
 		if ((result != GP_OK) || (evtype == GP_EVENT_TIMEOUT)) {
 			/*printf("Timeout or error, leaving loop.\n");*/
 			break;
